'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _jquery = require('jquery');

var _jquery2 = _interopRequireDefault(_jquery);

var _Html = require('gremlin-console/lib/Html');

var _Html2 = _interopRequireDefault(_Html);

var _Parser2 = require('gremlin-console/lib/Parser');

var _Parser3 = _interopRequireDefault(_Parser2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * Handles logic related to results sent back to the console
 * These can be custom crafted to suit different server outputs.
 * Either because of a custom serializer or if a call is made to a server side script.
 * It also allows for a change in the way the elements are displayed in html and how the history entries are generated
 *
 * @author Dylan Millikin <dylan.millikin@gmail.com>
 */

var GraphSONTextParser = function (_Parser) {
    _inherits(GraphSONTextParser, _Parser);

    function GraphSONTextParser() {
        _classCallCheck(this, GraphSONTextParser);

        return _possibleConstructorReturn(this, Object.getPrototypeOf(GraphSONTextParser).apply(this, arguments));
    }

    _createClass(GraphSONTextParser, [{
        key: 'create',


        /**
         * Creates a Parser object
         *
         * @param  {Error} err     A potential error from the database.
         * @param  {Mixed} results The server results for a query
         * @return {Parser} A populated Parser object
         */
        value: function create(err, results) {
            return new GraphSONTextParser(err, results);
        }

        /**
         * Get generic results.
         * These results are constructed in a way the console can comprehend them.
         * Extend this if you're receiving non conventional data from the server
         *
         * @return {Mixed} raw server results
         */

    }, {
        key: 'getResults',
        value: function getResults() {
            if (this.getRawResults() !== null && typeof this.getRawResults()[0] !== "undefined" && typeof this.getRawResults()[0].json !== "undefined") {
                return this.getRawResults()[0].json;
            } else {
                return [];
            }
        }

        /**
         * get the HTML results to put into the window dom element
         * Extend this for custom behavior
         *
         * @return {String|DOM} the element you want to append to the console window
         */

    }, {
        key: 'getHtmlResults',
        value: function getHtmlResults() {
            var textResultSet = '';
            if (this.getRawResults() !== null && typeof this.getRawResults()[0] !== "undefined" && typeof this.getRawResults()[0].text !== "undefined") {
                this.getRawResults()[0].text.forEach(function (entry) {
                    textResultSet += '==>' + _Html2.default.jsonSyntaxHighlight(entry) + '<br/>';
                });
                var jsonResultSet = '';
                this.getResults().forEach(function (entry) {
                    jsonResultSet += _Html2.default.jsonSyntaxHighlight(entry) + '<br/>';
                });
                return (0, _jquery2.default)('<div>').append((0, _jquery2.default)('<div>').addClass("port-response text").html(textResultSet)).append((0, _jquery2.default)('<div>').hide().addClass("port-response json").html(jsonResultSet)).html();
            } else {
                return '';
            }
        }

        /**
         * get the HTML error to put into the window dom element
         * Extend this for custom behavior
         *
         * @return {String|DOM} the element you want to append to the console window
         */

    }, {
        key: 'getHtmlError',
        value: function getHtmlError() {
            return (0, _jquery2.default)('<div>').addClass("port-error").html('Could not complete query => ' + _Html2.default.htmlEncode(this.getError().message));
        }
    }]);

    return GraphSONTextParser;
}(_Parser3.default);

exports.default = GraphSONTextParser;